# memphisdrip

A general library to expose utility functions used by [City-of-Memphis-Wastewater](https://github.com/City-of-Memphis-Wastewater/)

---

## (Some) Functions


| Function | Description |
| ------------- | ------------- |
| `typer_resolve_arg_flag_pair()` | Simplifies CLI logic by automatically selecting a value from either a positional argument or a named flag, ensuring the flag takes precedence and a valid result is returned. |

 
---

## Just for Fun

The best spots in Memphis

- Cxffeeblack
- Otherlands
- Loaf
- Black Lodge
- Aldar Cafe
- Java Cabana

